PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/analysis/prep.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Namespaces | Variables
prep.py File Reference

## Namespaces
| pawpyseed.analysis.prep

## Variables
list | pawpyseed.analysis.prep.filenames
list | pawpyseed.analysis.prep.names
| pawpyseed.analysis.prep.dpaths
list | pawpyseed.analysis.prep.defects = ["vac_1_Si", "sub_1_B_on_Si", "sub_1_P_on_Si", "sub_1_Cu_on_Si", "sub_1_S_on_Si"]
list | pawpyseed.analysis.prep.mathnames
list | pawpyseed.analysis.prep.charges = [[-2,-1,0,1,2], [-1,0], [0,1], [-1,0,1], [-2,-1,0,1,2,3]]
list | pawpyseed.analysis.prep.titles = []
string | pawpyseed.analysis.prep.my_dir = '/home/kyle/Research/projects/researchpapers/pawpyseed/thesis/results/projections'
| pawpyseed.analysis.prep.f = open('bandedges2.json', 'r')
| pawpyseed.analysis.prep.bandedges = yaml.load(f)
| pawpyseed.analysis.prep.be = bandedges[dp]
| pawpyseed.analysis.prep.bc = BulkCharacter.from_yaml(fname)
| pawpyseed.analysis.prep.efermi
| pawpyseed.analysis.prep.vbm
| pawpyseed.analysis.prep.cbm
| pawpyseed.analysis.prep.name
| pawpyseed.analysis.prep.spinpol
| pawpyseed.analysis.prep.True
| pawpyseed.analysis.prep.title